==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_va
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuelh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a ges d’article a aquela adreiça ',
	'aucun_auteur' => 'I a ges d’autor a aquela adreiça ',
	'aucun_site' => 'I a ges de sit a aquela adreiça ',
	'aucune_breve' => 'I a ges de brèva a aquela adreiça ',
	'aucune_rubrique' => 'I a ges de rubrica a aquela adreiça ',
	'autres_breves' => 'Autras brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bonjorn',

	// C
	'commenter_site' => 'Comentar aqueu sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrier apondon',
	'dernieres_breves' => 'Darrieras brèvas',
	'derniers_articles' => 'Darriers articles',
	'derniers_commentaires' => 'Darriers comentaris',
	'derniers_messages_forum' => 'Darriers messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En respònsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau mesme autor',
	'meme_rubrique' => 'Dins la mesma rubrica',
	'memes_auteurs' => 'Dels mesmes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo mesme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats sobre lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas nòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Poètz participar a la vita d’aqueu sit e prepausar los articles vòstres en vos inscrivent çai sos. Recebretz sus lo còp un e-mail que vos indicarà vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Poètz prepausar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respòndre a aquel article',
	'repondre_breve' => 'Respòndre a aquela brèva',
	'resultats_recherche' => 'Resultats de la recèrcha',
	'retour_debut_forums' => 'Retorn au començament dels forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat amb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'segua',
	'sur_web' => 'Sobre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa los articles e brèvas publicats despuei', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Veètz en linha'
);

==> spip_4.3.1+dfsg.orig.tar.xz: ecrire/lang/public_oc_va.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_va
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Acuelh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles d’aquel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles d’aquela rubrica',
	'aucun_article' => 'I a ges d’article a aquela adreiça ',
	'aucun_auteur' => 'I a ges d’autor a aquela adreiça ',
	'aucun_site' => 'I a ges de sit a aquela adreiça ',
	'aucune_breve' => 'I a ges de brèva a aquela adreiça ',
	'aucune_rubrique' => 'I a ges de rubrica a aquela adreiça ',
	'autres_breves' => 'Autras brèvas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bonjorn',

	// C
	'commenter_site' => 'Comentar aqueu sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrier apondon',
	'dernieres_breves' => 'Darrieras brèvas',
	'derniers_articles' => 'Darriers articles',
	'derniers_commentaires' => 'Darriers comentaris',
	'derniers_messages_forum' => 'Darriers messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde tèxt de',
	'en_reponse' => 'En respònsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau mesme autor',
	'meme_rubrique' => 'Dins la mesma rubrica',
	'memes_auteurs' => 'Dels mesmes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo mesme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats sobre lo web',
	'nouveaux_articles' => 'Articles nòus',
	'nouvelles_breves' => 'Brèvas nòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Poètz participar a la vita d’aqueu sit e prepausar los articles vòstres en vos inscrivent çai sos. Recebretz sus lo còp un e-mail que vos indicarà vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Poètz prepausar un sit d’apondre a aquesta rubrica:',

	// R
	'repondre_article' => 'Respòndre a aquel article',
	'repondre_breve' => 'Respòndre a aquela brèva',
	'resultats_recherche' => 'Resultats de la recèrcha',
	'retour_debut_forums' => 'Retorn au començament dels forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat amb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'segua',
	'sur_web' => 'Sobre lo web',
	'syndiquer_rubrique' => 'Sindicar aquela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Aquela letra recensa los articles e brèvas publicats despuei', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Veètz en linha',
];
